﻿import React, { Fragment } from "react";
import ReactDOM from "react-dom";
import {
  Viewer as ReportViewer,
  Designer,
} from "@grapecity/activereports-react";
import { PageReport } from "@grapecity/activereports/core";
import { exportDocument as pdfExport } from "@grapecity/activereports/pdfexport";
import { CustomCode } from "@grapecity/activereports/core";

function App() {
  const designer = React.useRef();
  const viewer = React.useRef();
  const [designerVisible, setDesignerVisible] = React.useState(true);
  function onDesignerOpen() {
    setDesignerVisible(true);
  }

  async function onPdfPreview() {
    const reportInfo = await designer.current.getReport();
    const report = new PageReport();
    await report.load(reportInfo.definition);
    const doc = await report.run();
    const result = await pdfExport(doc);
    result.download("exportedreport");
  }

  function onReportPreview(report) {
    setDesignerVisible(false);
    viewer.current.open(report.definition);
    return Promise.resolve();
  }

  return (
    <Fragment>
      <div id="designer-toolbar" class="container-fluid">
        <div class="row mt-3 mb-3">
          {designerVisible && (
            <button
              type="button"
              class="btn btn-primary btn-sm col-sm-2 ml-1"
              onClick={() => onPdfPreview()}
            >
              PDF Preview
            </button>
          )}
          {!designerVisible && (
            <button
              type="button"
              class="btn btn-primary btn-sm col-sm-2 ml-1"
              onClick={() => onDesignerOpen()}
            >
              Open Designer
            </button>
          )}
        </div>
      </div>
      <div
        id="designer-host"
        style={{ display: designerVisible ? "block" : "none" }}
      >
        <Designer
          report={{ id: "reports/CustomCodeReport.rdlx-json" }}
          ref={designer}
          onRender={onReportPreview}
        />
      </div>
      {!designerVisible && (
        <div id="viewer-host">
          <ReportViewer ref={viewer} />
        </div>
      )}
    </Fragment>
  );
}

function secondsToHms(time) {
  let hrs = Math.floor(time / 3600);
  let mins = Math.floor((time - 3600 * hrs) / 60);
  let secs = time - hrs * 3600 - mins * 60;

  if (hrs < 10) {
    hrs = "0" + hrs;
  }
  if (mins < 10) {
    mins = "0" + mins;
  }
  if (secs < 10) {
    secs = "0" + secs;
  }
  return hrs + ":" + mins + ":" + secs;
}

var customCode = [
  {
    name: "FormatSecondsToHMS",
    body: secondsToHms,
    info: {
      description: "Format seconds to HH:MM:SS",
      example: "Code.FormatSecondsToHMS(seconds)",
      syntax: "Code.FormatSecondsToHMS(<number>)",
    },
  },
];

CustomCode.registerFunctions(customCode);
ReactDOM.render(<App />, document.getElementById("root"));
